==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/SnowflakeImportCopyCommandArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Snowflake import command settings.
 * @property additionalCopyOptions Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
 * @property additionalFormatOptions Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
 * @property type The import setting type.
 * Expected value is 'SnowflakeImportCopyCommand'.
 */
public data class SnowflakeImportCopyCommandArgs(
    public val additionalCopyOptions: Output<Map<String, Any>>? = null,
    public val additionalFormatOptions: Output<Map<String, Any>>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs =
        com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs.builder()
            .additionalCopyOptions(
                additionalCopyOptions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .additionalFormatOptions(
                additionalFormatOptions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SnowflakeImportCopyCommandArgs].
 */
@PulumiTagMarker
public class SnowflakeImportCopyCommandArgsBuilder internal constructor() {
    private var additionalCopyOptions: Output<Map<String, Any>>? = null

    private var additionalFormatOptions: Output<Map<String, Any>>? = null

    private var type: Output<String>? = null

    /**
     * @param value Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
     */
    @JvmName("yjbbrvatnhxkyovf")
    public suspend fun additionalCopyOptions(`value`: Output<Map<String, Any>>) {
        this.additionalCopyOptions = value
    }

    /**
     * @param value Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
     */
    @JvmName("celmphakxrxvxpxh")
    public suspend fun additionalFormatOptions(`value`: Output<Map<String, Any>>) {
        this.additionalFormatOptions = value
    }

    /**
     * @param value The import setting type.
     * Expected value is 'SnowflakeImportCopyCommand'.
     */
    @JvmName("mdrnhmocmumgugtl")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
     */
    @JvmName("fgeltbbvqstolqlo")
    public suspend fun additionalCopyOptions(`value`: Map<String, Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalCopyOptions = mapped
    }

    /**
     * @param values Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
     */
    @JvmName("kfhupwebyqgpipxa")
    public fun additionalCopyOptions(vararg values: Pair<String, Any>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.additionalCopyOptions = mapped
    }

    /**
     * @param value Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
     */
    @JvmName("fhqpigfwawyqjasg")
    public suspend fun additionalFormatOptions(`value`: Map<String, Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalFormatOptions = mapped
    }

    /**
     * @param values Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
     */
    @JvmName("rofninqyxdyewexd")
    public fun additionalFormatOptions(vararg values: Pair<String, Any>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.additionalFormatOptions = mapped
    }

    /**
     * @param value The import setting type.
     * Expected value is 'SnowflakeImportCopyCommand'.
     */
    @JvmName("ilqyqwifurphtogp")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): SnowflakeImportCopyCommandArgs = SnowflakeImportCopyCommandArgs(
        additionalCopyOptions = additionalCopyOptions,
        additionalFormatOptions = additionalFormatOptions,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/SnowflakeImportCopyCommandArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Snowflake import command settings.
 * @property additionalCopyOptions Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
 * @property additionalFormatOptions Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
 * @property type The import setting type.
 * Expected value is 'SnowflakeImportCopyCommand'.
 */
public data class SnowflakeImportCopyCommandArgs(
    public val additionalCopyOptions: Output<Map<String, Any>>? = null,
    public val additionalFormatOptions: Output<Map<String, Any>>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs =
        com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs.builder()
            .additionalCopyOptions(
                additionalCopyOptions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .additionalFormatOptions(
                additionalFormatOptions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SnowflakeImportCopyCommandArgs].
 */
@PulumiTagMarker
public class SnowflakeImportCopyCommandArgsBuilder internal constructor() {
    private var additionalCopyOptions: Output<Map<String, Any>>? = null

    private var additionalFormatOptions: Output<Map<String, Any>>? = null

    private var type: Output<String>? = null

    /**
     * @param value Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
     */
    @JvmName("otlarmgstlkfqbpu")
    public suspend fun additionalCopyOptions(`value`: Output<Map<String, Any>>) {
        this.additionalCopyOptions = value
    }

    /**
     * @param value Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
     */
    @JvmName("eieonpxfgmaljdee")
    public suspend fun additionalFormatOptions(`value`: Output<Map<String, Any>>) {
        this.additionalFormatOptions = value
    }

    /**
     * @param value The import setting type.
     * Expected value is 'SnowflakeImportCopyCommand'.
     */
    @JvmName("kbwsrqfxwkpkebuv")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
     */
    @JvmName("bishawabitblycfe")
    public suspend fun additionalCopyOptions(`value`: Map<String, Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalCopyOptions = mapped
    }

    /**
     * @param values Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
     */
    @JvmName("xtlhrokkulsduiqx")
    public fun additionalCopyOptions(vararg values: Pair<String, Any>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.additionalCopyOptions = mapped
    }

    /**
     * @param value Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
     */
    @JvmName("tfaaaowgujbootwg")
    public suspend fun additionalFormatOptions(`value`: Map<String, Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalFormatOptions = mapped
    }

    /**
     * @param values Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
     */
    @JvmName("mgtxqamqgkgdyocg")
    public fun additionalFormatOptions(vararg values: Pair<String, Any>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.additionalFormatOptions = mapped
    }

    /**
     * @param value The import setting type.
     * Expected value is 'SnowflakeImportCopyCommand'.
     */
    @JvmName("wkvcskfqoibuvugx")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): SnowflakeImportCopyCommandArgs = SnowflakeImportCopyCommandArgs(
        additionalCopyOptions = additionalCopyOptions,
        additionalFormatOptions = additionalFormatOptions,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
